@@ -1,7 +1,7 @@
 package usww;
 use 5.012005;
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 use parent 'usw';
 
@@ -22,16 +22,15 @@ usww - was forked from usw especially for Windows.
  use strict;
  use warnings;
  my $cp = '__YourCP__' || 'UTF-8';
+ binmode \*STDIN,  ':encoding($cp)';
  binmode \*STDOUT, ':encoding($cp)';
  binmode \*STDERR, ':encoding($cp)';
-
-=cut #binmode \*STDIN,  ':encoding($cp)';
   
 =head1 DESCRIPTION
 
 usww is deprecated because L<usw> now adapt Windows.
 
-This document exists just only for backwards compatibility
+This document exists just only for backwards compatibility.
 
 =head1 LICENSE
 
